/**
 * See https://fdc3.finos.org/docs/fdc3-intro, and https://github.com/finos/FDC3/tree/master/src/api
 */
import { AppIntent, Channel, Context, ContextHandler, Intents, IntentResolution } from '@finos/fdc3';
import { Observable } from 'rxjs';
/**
 * @public
 */
export type FDC3Intents = Intents;
/**
 * @public
 */
export type FDC3ContextHandler = ContextHandler;
/**
 * @public
 */
export interface FDC3AppIntent extends AppIntent {
}
/**
 * @public
 */
export interface FDC3Context extends Context {
}
/**
 * @public
 */
export interface FDC3IntentResolution extends IntentResolution {
}
/**
 * @public
 */
export interface FDC3Channel extends Channel {
}
/**
 * The FDC3 API interface.
 * @public
 */
export interface FDC3 {
    /**
     * Whether the FDC3 API is ready.
     * @public
     */
    isReady: boolean;
    /**
     * Check if the interop global is available.
     * @public
     */
    isInteropFdc3: () => boolean;
    /**
     * Observable which emits the current channel
     * When a new channel is joined a new value is emitted
     * @public
     */
    currentChannelObs: Observable<FDC3Channel>;
    /**
     * Adds intent listeners for the specified intents.
     * @public
     * @param listeners - The intent listeners to add.
     */
    addIntentListeners(listeners: Map<FDC3Intents, FDC3ContextHandler>): void;
    /**
     * Finds an app that supports the specified intent.
     * @public
     * @param intent - The intent to find an app for.
     * @param context - The context to use.
     * @returns A promise that resolves with the app and its metadata.
     */
    findIntent(intent: FDC3Intents, context?: FDC3Context): Promise<FDC3AppIntent>;
    /**
     * Finds all the intents supported by the specified context.
     * @public
     * @param context - The context to use.
     * @returns A promise that resolves with an array of all matching intents and their metadata.
     */
    findIntentsByContext(context: FDC3Context): Promise<FDC3AppIntent[]>;
    /**
     * Raises an intent against an application based purely on the context data.
     * @public
     * @param context - The context to use.
     * @returns A promise that resolves with the result of the intent resolution.
     */
    raiseIntentForContext(context: FDC3Context): Promise<FDC3IntentResolution>;
    /**
     * Raises the specified intent with the specified context.
     * @public
     * @param context - The context to use.
     * @param intent - The intent to raise.
     * @returns A promise that resolves with the result of the intent resolution.
     */
    raiseIntent(context: FDC3Context, intent?: FDC3Intents): Promise<FDC3IntentResolution>;
    /**
     * Joins the specified channel.
     * @public
     * @param channelId - The ID of the channel to join.
     * @returns A promise that resolves when the join is successful.
     */
    joinChannel(channelId: string): Promise<void>;
    /**
     * Gets or creates the specified channel.
     * @public
     * @param  channelId - The ID of the channel to get or create.
     * @returns A promise that resolves with the channel object.
     */
    getOrCreateChannel(channelId: string): Promise<FDC3Channel>;
    /**
     * Broadcasts a message on a given channel with a given type
     * @param channelName - name of the channel
     * @param type - type of the channel
     * @param payload - payload sent to the channel
     */
    broadcastOnChannel(channelName: string, type: string, payload: any): Promise<void>;
    /**
     * Broadcasts a message on the current app channel
     * @param type - type of the channel
     * @param payload - payload sent to the channel
     */
    broadcastOnCurrentChannel(payload: any, type?: string): Promise<void>;
    /**
     * Helper function to broadcast message on channel in response to dispatched event
     * @param channelName - name of the channel
     * @param type - type of the channel
     */
    broadcastOnChannelEventHandler(channelName: string, type: string): Promise<(e: any) => Promise<void>>;
    /**
     * Helper function to add a context listener on a channel with a handler for channel messages
     * @param channel - instance of a channel
     * @param channelType - type of the channel context
     * @param callback - handler to for the channel context listener
     * */
    addChannelListener(channel: FDC3Channel | Channel, channelType: string, callback: (any: any) => void): Promise<Channel>;
    /**
     * Helper function to get the current channel of the application
     * */
    getCurrentChannel(): Promise<Channel>;
}
/**
 * The FDC3 implementation.
 * @internal
 */
export declare class DefaultFDC3 implements FDC3 {
    isReady: boolean;
    private _currentChannel$;
    private _currentChannel;
    currentChannelObs: Observable<Channel>;
    isInteropFdc3: () => boolean;
    constructor();
    private connect;
    addIntentListeners(listeners: Map<FDC3Intents, FDC3ContextHandler>): void;
    findIntent(intent: FDC3Intents, context?: FDC3Context): Promise<FDC3AppIntent>;
    findIntentsByContext(context: FDC3Context): Promise<FDC3AppIntent[]>;
    raiseIntentForContext(context: FDC3Context): Promise<FDC3IntentResolution>;
    raiseIntent(context: FDC3Context, intent: FDC3Intents): Promise<FDC3IntentResolution>;
    joinChannel(channelId: string): Promise<void>;
    getOrCreateChannel(channelId: string): Promise<FDC3Channel>;
    broadcastOnChannel(channelName: string, type: string, payload: any): Promise<void>;
    broadcastOnCurrentChannel(payload: any, type?: string): Promise<void>;
    broadcastOnChannelEventHandler(channelName: string, type: string): Promise<(e: any) => Promise<void>>;
    addChannelListener(channel: FDC3Channel | Channel, channelType: string, callback: (any: any) => void): Promise<FDC3Channel | Channel>;
    getCurrentChannel(): Promise<Channel>;
    private broadcastMessageOnChannel;
}
/**
 * The DI token for the FDC3 interface.
 * @internal
 */
export declare const FDC3: import("@microsoft/fast-foundation").InterfaceSymbol<FDC3>;
//# sourceMappingURL=fdc3.d.ts.map